==> lxqt-l10n-0.11.0-1-src.tar.xz: lxqt-l10n-0.11.0/lxqt-config/lxqt-config-locale/lxqt-config-locale_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../../../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>Re&amp;gione:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>Impos&amp;tazioni dettagliate</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Numeri:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>&amp;Ora:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Valuta:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Unità di misura:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>Ordi&amp;namento:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;Esempi&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>Numeri:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>Ora:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>Valuta:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>Unità di misura:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="119"/>
        <source>No change</source>
        <translation>Nessuna modifica</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="308"/>
        <source>Format Settings Changed</source>
        <translation>Impostazioni di formato cambiate</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="309"/>
        <source>Save the settings ? (they will take effect the next time you log in)</source>
        <translation>Vuoi salvare le impostazioni? (avranno effetto al prossimo accesso)</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="430"/>
        <source>Imperial UK</source>
        <translation>Imperiale GB</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="434"/>
        <source>Imperial US</source>
        <translation>Imperiale USA</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="438"/>
        <source>Metric</source>
        <translation>Metrico</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="38"/>
        <source>LXQt Locale Configuration</source>
        <translation>Configurazione localizzazione di LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="43"/>
        <source>Locale Settings</source>
        <translation>Impostazioni di localizzazione</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.12.0-1-src.tar.xz: lxqt-l10n-0.12.0/lxqt-config/lxqt-config-locale/lxqt-config-locale_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../../../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>Re&amp;gione:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>Impos&amp;tazioni dettagliate</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>&amp;Numeri:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>&amp;Ora:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Valuta:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Unità di misura:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>Ordi&amp;namento:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;Esempi&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>Numeri:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>Ora:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>Valuta:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>Unità di misura:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="119"/>
        <source>No change</source>
        <translation>Nessuna modifica</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="308"/>
        <source>Format Settings Changed</source>
        <translation>Impostazioni di formato cambiate</translation>
    </message>
    <message>
        <source>Save the settings ? (they will take effect the next time you log in)</source>
        <translation type="vanished">Vuoi salvare le impostazioni? (avranno effetto al prossimo accesso)</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="309"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="430"/>
        <source>Imperial UK</source>
        <translation>Imperiale GB</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="434"/>
        <source>Imperial US</source>
        <translation>Imperiale USA</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="438"/>
        <source>Metric</source>
        <translation>Metrico</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>Configurazione della lingua e del paese di LXQt</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>Impostazioni di localizzazione</translation>
    </message>
</context>
</TS>
